package de.intevation.flys.client.client.ui.chart;

import com.google.gwt.core.client.GWT;

import com.smartgwt.client.widgets.Button;
import com.smartgwt.client.widgets.Canvas;
import com.smartgwt.client.widgets.ImgButton;
import com.smartgwt.client.widgets.Label;
import com.smartgwt.client.widgets.events.ClickEvent;
import com.smartgwt.client.widgets.events.ClickHandler;

import de.intevation.flys.client.client.FLYSConstants;
import de.intevation.flys.client.client.ui.CollectionView;
import de.intevation.flys.client.client.ui.ImgLink;
import de.intevation.flys.client.client.ui.Toolbar;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ChartToolbar extends Toolbar {

    protected static FLYSConstants MSG = GWT.create(FLYSConstants.class);


    public static final int PANEL_HEIGHT = 30;


    protected ChartOutputTab chartTab;


    protected Button datacage;

    protected Canvas downloadPNG;

    protected Canvas downloadPDF;

    protected Canvas downloadSVG;

    protected MousePositionPanel position;

    protected ZoomboxControl zoombox;

    protected ImgButton zoomToMaxExtent;

    protected ImgButton historyBack;

    protected ImgButton zoomOut;

    protected ImgButton chartProperties;

    protected PanControl panControl;



    public ChartToolbar(CollectionView view, ChartOutputTab chartTab) {
        super(chartTab);

        this.chartTab   = chartTab;
        datacage        = new Button(MSG.databasket());
        position        = new MousePositionPanel(chartTab);
        zoombox         = new ZoomboxControl(chartTab, MSG.zoom_in());
        zoomToMaxExtent = new ImgButton();
        zoomOut         = new ImgButton();
        historyBack     = new ImgButton();
        panControl      = new PanControl(chartTab, MSG.pan());
        chartProperties = new ImgButton();

        datacage.addClickHandler(new ClickHandler() {
            public void onClick(ClickEvent event) {
                GWT.log("Clicked 'datacage' button.");
                openDatacageWindow((ChartOutputTab) getOutputTab());
            }
        });

        String baseUrl = GWT.getHostPageBaseURL();

        downloadPNG = new ImgLink(
            baseUrl + MSG.downloadPNG(),
            chartTab.getExportUrl(-1, -1, "png"),
            20,
            20);

        downloadPDF = new ImgLink(
            baseUrl + MSG.downloadPDF(),
            chartTab.getExportUrl(1280, 1024, "pdf"),
            20,
            20);

        downloadSVG = new ImgLink(
            baseUrl + MSG.downloadSVG(),
            chartTab.getExportUrl(1280, 1024, "svg"),
            20,
            20);

        zoomToMaxExtent.setSrc(baseUrl + MSG.zoom_all());
        zoomToMaxExtent.setWidth(20);
        zoomToMaxExtent.setHeight(20);
        zoomToMaxExtent.setShowDown(false);
        zoomToMaxExtent.setShowRollOver(false);
        zoomToMaxExtent.setShowDisabled(false);
        zoomToMaxExtent.setShowDisabledIcon(true);
        zoomToMaxExtent.setShowDownIcon(false);
        zoomToMaxExtent.setShowFocusedIcon(false);
        zoomToMaxExtent.addClickHandler(new ClickHandler() {
            public void onClick(ClickEvent event) {
                getChartOutputTab().resetRanges();
            }
        });

        zoomOut.setSrc(baseUrl + MSG.zoom_out());
        zoomOut.setWidth(20);
        zoomOut.setHeight(20);
        zoomOut.setShowDown(false);
        zoomOut.setShowRollOver(false);
        zoomOut.setShowDisabled(false);
        zoomOut.setShowDisabledIcon(true);
        zoomOut.setShowDownIcon(false);
        zoomOut.setShowFocusedIcon(false);
        zoomOut.addClickHandler(new ClickHandler() {
            public void onClick(ClickEvent event) {
                getChartOutputTab().zoomOut(10);
            }
        });

        historyBack.setSrc(baseUrl + MSG.zoom_back());
        historyBack.setWidth(20);
        historyBack.setHeight(20);
        historyBack.setShowDown(false);
        historyBack.setShowRollOver(false);
        historyBack.setShowDisabled(false);
        historyBack.setShowDisabledIcon(true);
        historyBack.setShowDownIcon(false);
        historyBack.setShowFocusedIcon(false);
        historyBack.addClickHandler(new ClickHandler() {
            public void onClick(ClickEvent event) {
                getChartOutputTab().zoomOut();
            }
        });

        zoombox.addZoomHandler(chartTab);
        zoombox.addClickHandler(new ClickHandler() {
            public void onClick(ClickEvent event) {
                panControl.deselect();
            }
        });

        panControl.addPanHandler(chartTab);
        panControl.addClickHandler(new ClickHandler() {
            public void onClick(ClickEvent event) {
                zoombox.deselect();
            }
        });

        chartProperties.setSrc(baseUrl + MSG.properties_ico());
        chartProperties.setWidth(20);
        chartProperties.setHeight(20);
        chartProperties.setShowDown(false);
        chartProperties.setShowRollOver(false);
        chartProperties.setShowDisabled(false);
        chartProperties.setShowDisabledIcon(true);
        chartProperties.setShowDownIcon(false);
        chartProperties.setShowFocusedIcon(false);
        chartProperties.addClickHandler(new ClickHandler() {
            public void onClick(ClickEvent event) {
                openPropertiesEditor();
            }
        });

        initLayout();
    }


    public ChartOutputTab getChartOutputTab() {
        return chartTab;
    }


    protected void initLayout() {
        setWidth100();
        setHeight(PANEL_HEIGHT);
        setMembersMargin(10);
        setPadding(5);
        setBorder("1px solid black");

        Label spacer = new Label();
        spacer.setWidth("*");
        datacage.setWidth("95px");
        position.setWidth("200px");

        addMember(datacage);
        addMember(downloadPNG);
        addMember(downloadPDF);
        addMember(downloadSVG);
        addMember(zoomToMaxExtent);
        addMember(historyBack);
        addMember(zoomOut);
        addMember(zoombox);
        addMember(panControl);
        addMember(chartProperties);
        addMember(spacer);
        addMember(position);
    }

    /**
     * Open the chart property editor dialog.
     */
    protected void openPropertiesEditor() {
        ChartPropertiesEditor editor =
            new ChartPropertiesEditor(getChartOutputTab());
        editor.show();
    }

}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
